@@ -13,7 +13,7 @@ Tk::ITree - Shamelessly copied Tk::Tree widget
 =cut
 
 use vars qw($VERSION);
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use Tk ();
 use Tk::Derived;
@@ -72,6 +72,11 @@ to an internal bitmap in this package.
 Set or get the I<plus> indicator image. By default it is set
 to an internal bitmap in this package.
 
+=item Switch: B<-leftrightcall>
+
+This callback is executed when the user presses the right or left arrow key.
+The call gets 'left' or 'right' and the name of the selected entry as parameter.
+
 =back
 
 =cut
@@ -86,6 +91,7 @@ sub Populate
  my $fg = $l->cget('-foreground');
  $l->destroy;
  $w->ConfigSpecs(
+	-closecmd     => ['CALLBACK', 'closeCmd',     'CloseCmd', 'CloseCmd'],
 	-indicatorminusimg => ['PASSIVE', undef, undef, $w->Bitmap(
 		-data => $minusimg,
 		-foreground => $fg,
@@ -94,14 +100,14 @@ sub Populate
 		-data => $plusimg,
 		-foreground => $fg,
 	)],
-	-ignoreinvoke => ['PASSIVE',  'ignoreInvoke', 'IgnoreInvoke', 0],
-	-opencmd      => ['CALLBACK', 'openCmd',      'OpenCmd', 'OpenCmd' ],
-	-indicatorcmd => ['CALLBACK', 'indicatorCmd', 'IndicatorCmd', 'IndicatorCmd'],
-	-closecmd     => ['CALLBACK', 'closeCmd',     'CloseCmd', 'CloseCmd'],
-	-indicator    => ['SELF', 'indicator', 'Indicator', 1],
 	-indent       => ['SELF', 'indent', 'Indent', 20],
-	-width        => ['SELF', 'width', 'Width', 20],
+	-indicator    => ['SELF', 'indicator', 'Indicator', 1],
+	-indicatorcmd => ['CALLBACK', 'indicatorCmd', 'IndicatorCmd', 'IndicatorCmd'],
+	-ignoreinvoke => ['PASSIVE',  'ignoreInvoke', 'IgnoreInvoke', 0],
 	-itemtype     => ['SELF', 'itemtype', 'Itemtype', 'imagetext'],
+	-leftrightcall => ['CALLBACK', undef, undef, sub {}],
+	-opencmd      => ['CALLBACK', 'openCmd',      'OpenCmd', 'OpenCmd' ],
+	-width        => ['SELF', 'width', 'Width', 20],
  );
 }
 
@@ -381,6 +387,7 @@ sub LeftRight {
 		} elsif ($spec eq 'right') {
 			$self->Activate($sel, 'open'); 
 		}
+		$self->Callback('-leftrightcall', $spec, $sel);
 	}
 	$self->SUPER::LeftRight($spec)
 }
@@ -415,3 +422,5 @@ __END__
 
 
 
+
+
